# dapodik

[![dapodik - PyPi](https://img.shields.io/pypi/v/dapodik)](https://pypi.org/project/dapodik/)
[![Telegram Group](https://img.shields.io/badge/Telegram-Group-blue.svg)](https://t.me/dapodik_2021)
[![Donate DANA](https://img.shields.io/badge/Donasi-DANA-blue)](https://link.dana.id/qr/1lw2r12r)
[![Download](https://img.shields.io/badge/D-Download-brightgreen)](https://github.com/hexatester/dapodik/archive/master.zip)
[![Tutorial](https://img.shields.io/badge/Tutorial-Usage-informational)](https://github.com/hexatester/dapodik/wiki)
[![LICENSE](https://img.shields.io/github/license/hexatester/dapodik)](https://github.com/hexatester/dapodik/blob/master/LICENSE)

Alat bantu aplikasi dapodik.

## Legal

This code is in no way affiliated with, authorized, maintained, sponsored or endorsed by [Kemdikbud](https://kemdikbud.go.id/) or any of its affiliates or subsidiaries. This is an independent and unofficial software. _Use at your own risk._
